Skip to contents

Used internally. See the setup_trial() function documentation for additional details on how to specify functions to generate posterior draws.

Arguments

arms

character vector, currently active arms as specified in setup_trial() / setup_trial_binom() / setup_trial_norm().

allocs

character vector, allocations of all participants (including allocations to currently inactive arms).

ys

numeric vector, outcomes of all participants in the same order as alloc (including outcomes of participants in currently inactive arms).

control

unused argument in the built-in functions for setup_trial_binom() and setup_trial_norm, but required as this argument is supplied by the run_trial() function, and may be used in user-defined functions used to generate posterior draws.

n_draws

single integer, number of posterior draws.

Value

A matrix (with numeric values) with length(arms) columns and n_draws rows, with arms as column names.