Used internally. This function generates draws from posterior, normal
distributions for continuous outcomes. Technically, these posteriors use no
priors (for simulation speed), corresponding to the use of improper flat
priors. These posteriors correspond (and give similar results) to using
normal-normal models (normally distributed outcome, conjugate normal prior)
for each arm, assuming that a non-informative, flat prior is used. Thus, the
posteriors directly correspond to normal distributions with each groups' mean
as the mean and each groups' standard error as the standard deviation.
As it is necessary to always return valid draws, in cases where < 2
participants have been randomised to an arm, posterior draws will come from
an extremely wide normal distribution with mean corresponding to the mean of
all included participants with outcome data and a standard deviation
corresponding to the difference between the highest and lowest recorded
outcomes for all participants with available outcome data multiplied by
1000.
Arguments
- arms
character vector, currently active
armsas specified insetup_trial()/setup_trial_binom()/setup_trial_norm().- allocs
character vector, allocations of all participants (including allocations to currently inactive
arms).- ys
numeric vector, outcomes of all participants in the same order as
alloc(including outcomes of participants in currently inactivearms).- control
unused argument in the built-in functions for
setup_trial_binom()and setup_trial_norm, but required as this argument is supplied by therun_trial()function, and may be used in user-defined functions used to generate posterior draws.- n_draws
single integer, number of posterior draws.